@@ -42,6 +42,7 @@ class Dialect(metaclass=_Dialect):
     escape = "'"
     index_offset = 0
     unnest_column_only = False
+    alias_post_tablesample = False
 
     date_format = "'%Y-%m-%d'"
     dateint_format = "'%Y%m%d'"
@@ -106,6 +107,7 @@ class Dialect(metaclass=_Dialect):
             **{
                 "index_offset": self.index_offset,
                 "unnest_column_only": self.unnest_column_only,
+                "alias_post_tablesample": self.alias_post_tablesample,
                 **opts,
             },
         )
@@ -121,6 +123,7 @@ class Dialect(metaclass=_Dialect):
                 "time_mapping": self.inverse_time_mapping,
                 "time_trie": self.inverse_time_trie,
                 "unnest_column_only": self.unnest_column_only,
+                "alias_post_tablesample": self.alias_post_tablesample,
                 **opts,
             }
         )
