@@ -1,14 +1,21 @@
 from sqlglot import exp
 from sqlglot.dialects.dialect import (
     Dialect,
-    rename_func,
     no_tablesample_sql,
     no_trycast_sql,
+    rename_func,
 )
 from sqlglot.generator import Generator
+from sqlglot.tokens import Tokenizer, TokenType
 
 
 class SQLite(Dialect):
+    class Tokenizer(Tokenizer):
+        KEYWORDS = {
+            **Tokenizer.KEYWORDS,
+            "AUTOINCREMENT": TokenType.AUTO_INCREMENT,
+        }
+
     class Generator(Generator):
         TYPE_MAPPING = {
             exp.DataType.Type.BOOLEAN: "INTEGER",
@@ -24,6 +31,10 @@ class SQLite(Dialect):
             exp.DataType.Type.BINARY: "BLOB",
         }
 
+        TOKEN_MAPPING = {
+            TokenType.AUTO_INCREMENT: "AUTOINCREMENT",
+        }
+
         TRANSFORMS = {
             **Generator.TRANSFORMS,
             exp.Levenshtein: rename_func("EDITDIST3"),
