@@ -56,6 +56,10 @@ class Expression(metaclass=_Expression):
     def this(self):
         return self.args.get("this")
 
+    @property
+    def expression(self):
+        return self.args.get("expression")
+
     @property
     def expressions(self):
         return self.args.get("expressions") or []
@@ -537,6 +541,7 @@ class ColumnDef(Expression):
         "default": False,
         "not_null": False,
         "primary": False,
+        "unique": False,
     }
 
 
@@ -591,6 +596,10 @@ class Partition(Expression):
     pass
 
 
+class Fetch(Expression):
+    arg_types = {"direction": False, "count": True}
+
+
 class Group(Expression):
     arg_types = {
         "expressions": False,
@@ -830,7 +839,7 @@ class Union(Subqueryable, Expression):
 
     @property
     def right(self):
-        return self.args.get("expression")
+        return self.expression
 
 
 class Except(Union):
@@ -1485,7 +1494,7 @@ class Binary(Expression):
 
     @property
     def right(self):
-        return self.args.get("expression")
+        return self.expression
 
 
 class Add(Binary):
