@@ -4,7 +4,7 @@ from sqlglot import exp
 from sqlglot.errors import ErrorLevel, UnsupportedError
 from sqlglot.helper import apply_index_offset, csv, ensure_list
 from sqlglot.time import format_time
-from sqlglot.tokens import Tokenizer
+from sqlglot.tokens import TokenType, Tokenizer
 
 
 logger = logging.getLogger("sqlglot")
@@ -43,6 +43,8 @@ class Generator:
 
     TYPE_MAPPING = {}
 
+    TOKEN_MAPPING = {}
+
     __slots__ = (
         "time_mapping",
         "time_trie",
@@ -242,14 +244,17 @@ class Generator:
         default = self.sql(expression, "default")
         default = f" DEFAULT {default}" if default else ""
         auto_increment = (
-            " AUTO_INCREMENT" if expression.args.get("auto_increment") else ""
+            " " + self.token_sql(TokenType.AUTO_INCREMENT)
+            if expression.args.get("auto_increment")
+            else ""
         )
         collate = self.sql(expression, "collate")
         collate = f" COLLATE {collate}" if collate else ""
         comment = self.sql(expression, "comment")
         comment = f" COMMENT {comment}" if comment else ""
         primary = " PRIMARY KEY" if expression.args.get("primary") else ""
-        return f"{column} {kind}{not_null}{default}{collate}{auto_increment}{comment}{primary}"
+        unique = " UNIQUE" if expression.args.get("unique") else ""
+        return f"{column} {kind}{not_null}{default}{collate}{comment}{unique}{primary}{auto_increment}"
 
     def create_sql(self, expression):
         this = self.sql(expression, "this")
@@ -339,6 +344,13 @@ class Generator:
             ),
         )
 
+    def fetch_sql(self, expression):
+        direction = expression.args.get("direction")
+        direction = f" {direction.upper()}" if direction else ""
+        count = expression.args.get("count")
+        count = f" {count}" if count else ""
+        return f"{self.seg('FETCH')}{direction}{count} ROWS ONLY"
+
     def filter_sql(self, expression):
         this = self.sql(expression, "this")
         where = self.sql(expression, "expression")[1:]  # where has a leading space
@@ -491,7 +503,7 @@ class Generator:
 
     def lambda_sql(self, expression):
         args = self.expressions(expression, flat=True)
-        args = f"({args})" if len(args) > 1 else args
+        args = f"({args})" if len(args.split(",")) > 1 else args
         return self.no_identify(lambda: f"{args} -> {self.sql(expression, 'this')}")
 
     def lateral_sql(self, expression):
@@ -907,3 +919,6 @@ class Generator:
         op = self.seg(op)
         expression = self.sql(expression, "expression")
         return f"{this}{op}{self.sep()}{expression}"
+
+    def token_sql(self, token_type):
+        return self.TOKEN_MAPPING.get(token_type, token_type.name)
