@@ -1,14 +1,14 @@
 from sqlglot.optimizer.normalize import normalize
-from sqlglot.optimizer.decorrelate_subqueries import decorrelate_subqueries
 from sqlglot.optimizer.eliminate_subqueries import eliminate_subqueries
-from sqlglot.optimizer.isolate_table_selects import isolate_table_selects
 from sqlglot.optimizer.expand_multi_table_selects import expand_multi_table_selects
+from sqlglot.optimizer.isolate_table_selects import isolate_table_selects
 from sqlglot.optimizer.optimize_joins import optimize_joins
 from sqlglot.optimizer.pushdown_predicates import pushdown_predicates
 from sqlglot.optimizer.pushdown_projections import pushdown_projections
 from sqlglot.optimizer.qualify_tables import qualify_tables
 from sqlglot.optimizer.qualify_columns import qualify_columns
 from sqlglot.optimizer.quote_identities import quote_identities
+from sqlglot.optimizer.unnest_subqueries import unnest_subqueries
 
 
 def optimize(expression, schema=None, db=None, catalog=None):
@@ -34,7 +34,7 @@ def optimize(expression, schema=None, db=None, catalog=None):
     expression = qualify_columns(expression, schema)
     expression = pushdown_projections(expression)
     expression = normalize(expression)
-    expression = decorrelate_subqueries(expression)
+    expression = unnest_subqueries(expression)
     expression = expand_multi_table_selects(expression)
     expression = pushdown_predicates(expression)
     expression = optimize_joins(expression)
