@@ -88,11 +88,15 @@ class Parser:
         TokenType.ESCAPE,
         TokenType.EXPLAIN,
         TokenType.FALSE,
+        TokenType.FIRST,
         TokenType.FOLLOWING,
         TokenType.FUNCTION,
         TokenType.IF,
         TokenType.INTERVAL,
         TokenType.LAZY,
+        TokenType.LOCATION,
+        TokenType.NEXT,
+        TokenType.ONLY,
         TokenType.OPTIMIZE,
         TokenType.OPTIONS,
         TokenType.ORDINALITY,
@@ -103,12 +107,15 @@ class Parser:
         TokenType.SCHEMA_COMMENT,
         TokenType.SET,
         TokenType.SHOW,
+        TokenType.STORED,
         TokenType.TABLE,
         TokenType.TEMPORARY,
         TokenType.TOP,
         TokenType.TRUNCATE,
         TokenType.TRUE,
         TokenType.UNBOUNDED,
+        TokenType.UNIQUE,
+        TokenType.PROPERTIES,
         *SUBQUERY_PREDICATES,
         *TYPE_TOKENS,
     }
@@ -123,9 +130,11 @@ class Parser:
         TokenType.CURRENT_TIMESTAMP,
         TokenType.EXTRACT,
         TokenType.FILTER,
+        TokenType.FIRST,
         TokenType.OFFSET,
         TokenType.PRIMARY_KEY,
         TokenType.REPLACE,
+        TokenType.ROWS,
         TokenType.UNNEST,
         TokenType.VAR,
         TokenType.LEFT,
@@ -604,6 +613,14 @@ class Parser:
                         value=exp.Literal.string(self._parse_var().text("this")),
                     )
                 )
+            if self._match(TokenType.LOCATION):
+                properties.append(
+                    self.expression(
+                        exp.Property,
+                        this=exp.Literal.string(c.LOCATION),
+                        value=self._parse_string(),
+                    )
+                )
 
             if self._match(TokenType.PROPERTIES):
                 self._match_l_paren()
@@ -1105,9 +1122,18 @@ class Parser:
         return self.expression(exp.Ordered, this=this, desc=self._match(TokenType.DESC))
 
     def _parse_limit(self, this=None, top=False):
-        if not self._match(TokenType.TOP if top else TokenType.LIMIT):
-            return this
-        return self.expression(exp.Limit, this=this, expression=self._parse_number())
+        if self._match(TokenType.TOP if top else TokenType.LIMIT):
+            return self.expression(
+                exp.Limit, this=this, expression=self._parse_number()
+            )
+        if self._match(TokenType.FETCH):
+            direction = self._match_set((TokenType.FIRST, TokenType.NEXT))
+            direction = self._prev.text if direction else "FIRST"
+            count = self._parse_number()
+            self._match(TokenType.ROWS)
+            self._match(TokenType.ONLY)
+            return self.expression(exp.Fetch, direction=direction, count=count)
+        return this
 
     def _parse_offset(self, this=None):
         if not self._match(TokenType.OFFSET):
@@ -1173,14 +1199,14 @@ class Parser:
             )
         elif self._match(TokenType.IN):
             self._match_l_paren()
-            query = self._parse_with()
+            expressions = self._parse_csv(
+                lambda: self._parse_expression() or self._parse_with()
+            )
 
-            if query:
-                this = self.expression(exp.In, this=this, query=query)
+            if len(expressions) == 1 and isinstance(expressions[0], exp.Subqueryable):
+                this = self.expression(exp.In, this=this, query=expressions[0])
             else:
-                this = self.expression(
-                    exp.In, this=this, expressions=self._parse_csv(self._parse_term)
-                )
+                this = self.expression(exp.In, this=this, expressions=expressions)
 
             self._match_r_paren()
         elif self._match(TokenType.BETWEEN):
@@ -1338,10 +1364,16 @@ class Parser:
             return self.PRIMARY_PARSERS[self._prev.token_type](self, self._prev)
 
         if self._match(TokenType.L_PAREN):
-            this = self._parse_conjunction() or self._parse_with()
+            expressions = self._parse_csv(self._parse_conjunction) or [
+                self._parse_with()
+            ]
+            this = list_get(expressions, 0)
+
             self._match_r_paren()
             if self._return_subquery and isinstance(this, exp.Subqueryable):
                 return self._parse_subquery(this)
+            if len(expressions) > 1:
+                return self.expression(exp.Tuple, expressions=expressions)
             return self.expression(exp.Paren, this=this)
 
         return None
@@ -1460,6 +1492,7 @@ class Parser:
             "comment": None,
             "default": None,
             "primary": None,
+            "unique": None,
             "parsed": True,
         }
 
@@ -1495,6 +1528,7 @@ class Parser:
                 "primary",
                 lambda: self._match(TokenType.PRIMARY_KEY),
             )
+            parse_option("unique", lambda: self._match(TokenType.UNIQUE))
 
         options.pop("parsed")
         return self.expression(exp.ColumnDef, this=this, kind=kind, **options)
@@ -1554,7 +1588,7 @@ class Parser:
         return self._parse_window(this)
 
     def _parse_extract(self):
-        this = self._parse_var()
+        this = self._parse_var() or self._parse_type()
 
         if not self._match(TokenType.FROM):
             self.raise_error("Expected FROM after EXTRACT", self._prev)
