@@ -119,7 +119,9 @@ class TokenType(AutoName):
     EXPLAIN = auto()
     EXTRACT = auto()
     FALSE = auto()
+    FETCH = auto()
     FILTER = auto()
+    FIRST = auto()
     FOLLOWING = auto()
     FULL = auto()
     FUNCTION = auto()
@@ -144,11 +146,14 @@ class TokenType(AutoName):
     LEFT = auto()
     LIKE = auto()
     LIMIT = auto()
+    LOCATION = auto()
     MAP = auto()
     MOD = auto()
+    NEXT = auto()
     NULL = auto()
     OFFSET = auto()
     ON = auto()
+    ONLY = auto()
     OPTIMIZE = auto()
     OPTIONS = auto()
     ORDER = auto()
@@ -204,6 +209,7 @@ class TokenType(AutoName):
     WITH_TIME_ZONE = auto()
     WITHIN_GROUP = auto()
     WITHOUT_TIME_ZONE = auto()
+    UNIQUE = auto()
 
 
 class Token:
@@ -352,7 +358,9 @@ class Tokenizer(metaclass=_Tokenizer):
         "EXPLAIN": TokenType.EXPLAIN,
         "EXTRACT": TokenType.EXTRACT,
         "FALSE": TokenType.FALSE,
+        "FETCH": TokenType.FETCH,
         "FILTER": TokenType.FILTER,
+        "FIRST": TokenType.FIRST,
         "FULL": TokenType.FULL,
         "FUNCTION": TokenType.FUNCTION,
         "FOLLOWING": TokenType.FOLLOWING,
@@ -376,10 +384,13 @@ class Tokenizer(metaclass=_Tokenizer):
         "LEFT": TokenType.LEFT,
         "LIKE": TokenType.LIKE,
         "LIMIT": TokenType.LIMIT,
+        "LOCATION": TokenType.LOCATION,
+        "NEXT": TokenType.NEXT,
         "NOT": TokenType.NOT,
         "NULL": TokenType.NULL,
         "OFFSET": TokenType.OFFSET,
         "ON": TokenType.ON,
+        "ONLY": TokenType.ONLY,
         "OPTIMIZE": TokenType.OPTIMIZE,
         "OPTIONS": TokenType.OPTIONS,
         "OR": TokenType.OR,
@@ -402,6 +413,7 @@ class Tokenizer(metaclass=_Tokenizer):
         "RIGHT": TokenType.RIGHT,
         "RLIKE": TokenType.RLIKE,
         "ROLLUP": TokenType.ROLLUP,
+        "ROW": TokenType.ROWS,
         "ROWS": TokenType.ROWS,
         "SELECT": TokenType.SELECT,
         "SET": TokenType.SET,
@@ -466,6 +478,7 @@ class Tokenizer(metaclass=_Tokenizer):
         "TIMESTAMPTZ": TokenType.TIMESTAMPTZ,
         "DATE": TokenType.DATE,
         "DATETIME": TokenType.DATETIME,
+        "UNIQUE": TokenType.UNIQUE,
     }
 
     WHITE_SPACE = {
